@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "avibase.h"
 
@@ -146,13 +146,12 @@ avi_copy (AviEdit    *avi_edit,
 
       /* ja:コピー */
       avi_file = g_malloc (sizeof (AviFile));
-
-      avi_file->fio = avi_edit->file->fio
-                    ? fileio_open (avi_edit->file->name, FILEIO_ACCESS_READ,
-                        FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING) : NULL;
-      avi_file->data = avi_edit->file->data && avi_edit->file->bmih
-                                ? g_memdup (avi_edit->file->data,
-                                bm_image_bytes (avi_edit->file->bmih)) : NULL;
+      avi_file->fio = avi_edit->file->fio;
+      if (avi_file->fio)
+        fileio_ref (avi_file->fio);
+      avi_file->avi_memory = avi_edit->file->avi_memory;
+      if (avi_file->avi_memory)
+        avi_memory_ref (avi_file->avi_memory);
       avi_file->name = g_strdup (avi_edit->file->name);
       avi_file->start = start_n - avi_edit->offset + avi_edit->file->start;
       avi_file->length
@@ -162,9 +161,12 @@ avi_copy (AviEdit    *avi_edit,
       avi_file->param = avi_edit->file->param;
       avi_file->index = g_memdup (avi_edit->file->index,
                                 avi_edit->file->entries * sizeof (AviIndex));
+      /* ja:ビデオ固有 */
       avi_file->handler = avi_edit->file->handler;
       avi_file->bmih = avi_edit->file->bmih ? g_memdup (avi_edit->file->bmih,
                                 bm_header_bytes (avi_edit->file->bmih)) : NULL;
+      /* ja:オーディオ固有 */
+      avi_file->samples = avi_edit->file->samples;
       avi_file->wfx = avi_edit->file->wfx ? g_memdup (avi_edit->file->wfx,
                                 wf_header_bytes (avi_edit->file->wfx)) : NULL;
       /* ja:リストに挿入する */
