@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -90,6 +90,18 @@ typedef struct _Chunk
     )
 
 
+/*  ja:4文字コードを大文字にする
+    fcc,4文字コード
+    RET,4文字コード                                                         */
+#define toupper4cc(fcc)                                                     \
+    make4cc(                                                                \
+        g_ascii_toupper(get4cc(fcc,0)),                                     \
+        g_ascii_toupper(get4cc(fcc,1)),                                     \
+        g_ascii_toupper(get4cc(fcc,2)),                                     \
+        g_ascii_toupper(get4cc(fcc,3))                                      \
+    )
+
+
 #define CK_DEF_RIFF             make4cc('R','I','F','F')
 #define CK_DEF_LIST             make4cc('L','I','S','T')
 #define CK_FORM_AVI             make4cc('A','V','I',' ')
@@ -102,7 +114,7 @@ typedef struct _Chunk
 #define CK_ID_AVIMAINHDR        make4cc('a','v','i','h')
 #define CK_ID_STREAMHEADER      make4cc('s','t','r','h')
 #define CK_ID_STREAMFORMAT      make4cc('s','t','r','f')
-#define CK_ID_STREAMHANDLERDATA	make4cc('s','t','r','d')
+#define CK_ID_STREAMHANDLERDATA make4cc('s','t','r','d')
 #define CK_ID_STREAMNAME        make4cc('s','t','r','n')
 #define CK_ID_AVINEWINDEX       make4cc('i','d','x','1')
 #define CK_ID_AVIPADDING        make4cc('J','U','N','K')
