@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,9 @@
 # include <tchar.h>
 # include <windows.h>
 # include <vfw.h>
+# ifdef G_OS_WIN32
+#  include <gdk/gdkwin32.h>
+# endif /* G_OS_WIN32 */
 #endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
 
 
@@ -369,7 +372,23 @@ icm_open (const guint32 handler,
                                 GPOINTER_TO_INT (&icinfo), sizeof (ICINFO));
           icm_object->name = g_utf16_to_utf8 (icinfo.szDescription, -1,
                                                             NULL, NULL, NULL);
-          icm_object->flags = 0;
+          if (!icm_object->name || icm_object->name[0] == '\0')
+            {
+              g_free (icm_object->name);
+              icm_object->name = g_utf16_to_utf8 (icinfo.szName, -1,
+                                                            NULL, NULL, NULL);
+            }
+          if (!icm_object->name || icm_object->name[0] == '\0')
+            {
+              g_free (icm_object->name);
+              icm_object->name = g_utf16_to_utf8 (icinfo.szDriver, -1,
+                                                            NULL, NULL, NULL);
+            }
+          if (!icm_object->name || icm_object->name[0] == '\0')
+            {
+              g_free (icm_object->name);
+              icm_object->name = icm_handler_to_string (handler);
+            }
           if (icinfo.dwFlags & VIDCF_QUALITY)
             icm_object->flags = ICM_FLAG_QUALITY;
           if (icinfo.dwFlags & VIDCF_CRUNCH)
@@ -393,27 +412,6 @@ icm_open (const guint32 handler,
 }
 
 
-/*  ja:Codecを閉じる
-    icm_object,IcmObject
-           RET,TRUE:正常終了,FALSE:エラー                                   */
-gboolean
-icm_close (IcmObject *icm_object)
-{
-  if (icm_object && --(icm_object->counter) <= 0)
-    {
-#if defined (G_OS_WIN32) || defined (USE_W32LDR)
-      CloseDriver (icm_object->hDrvr, 0, 0);
-#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
-      g_free (icm_object->name);
-      g_free (icm_object->bmih_in);
-      g_free (icm_object->bmih_out);
-      g_free (icm_object->prev);
-      g_free (icm_object);
-    }
-  return TRUE;
-}
-
-
 /*  ja:Codecの参照数を増やす
     icm_object,IcmObject
            RET,TRUE:正常終了,FALSE:エラー                                   */
@@ -430,7 +428,18 @@ icm_ref (IcmObject *icm_object)
 gboolean
 icm_unref (IcmObject *icm_object)
 {
-  return icm_close (icm_object);
+  if (icm_object && --(icm_object->counter) <= 0)
+    {
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+      CloseDriver (icm_object->hDrvr, 0, 0);
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+      g_free (icm_object->name);
+      g_free (icm_object->bmih_in);
+      g_free (icm_object->bmih_out);
+      g_free (icm_object->prev);
+      g_free (icm_object);
+    }
+  return TRUE;
 }
 
 
@@ -489,6 +498,79 @@ icm_get_attribute (IcmObject *icm_object)
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:ICMダイアログ                                                            *
+*                                                                             *
+******************************************************************************/
+/*  ja:Aboutダイアログのサポートを確認する
+    icm_object,IcmObject
+           RET,TRUE:有効,FALSE:無効                                         */
+gboolean
+icm_is_dialog_about (IcmObject *icm_object)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  return icm_object && icm_object->hDrvr
+        && SendDriverMessage (icm_object->hDrvr, ICM_ABOUT, -1, 0) == ICERR_OK;
+#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+  return FALSE;
+#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
+/*  ja:Aboutダイアログを表示する
+    icm_object,IcmObject
+        widget,親ウインドウ                                                 */
+void
+icm_dialog_about (IcmObject *icm_object,
+                  GtkWidget *widget)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  if (icm_object && icm_object->hDrvr)
+    SendDriverMessage (icm_object->hDrvr, ICM_ABOUT,
+# if defined (G_OS_WIN32)
+        widget ? GPOINTER_TO_INT (GDK_WINDOW_HWND (widget->window)) : 0, 0);
+# elif defined (USE_W32LDR)
+                                                GPOINTER_TO_INT (widget), 0);
+# endif /* defined (USE_W32LDR) */
+#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
+/*  ja:設定ダイアログのサポートを確認する
+    icm_object,IcmObject
+           RET,TRUE:有効,FALSE:無効                                         */
+gboolean
+icm_is_dialog_configure (IcmObject *icm_object)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  return icm_object && icm_object->hDrvr
+    && SendDriverMessage (icm_object->hDrvr, ICM_CONFIGURE, -1, 0) == ICERR_OK;
+#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+  return FALSE;
+#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
+/*  ja:設定ダイアログを表示する
+    icm_object,IcmObject
+        widget,親ウインドウ                                                 */
+void
+icm_dialog_configure (IcmObject *icm_object,
+                      GtkWidget *widget)
+{
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+  if (icm_object && icm_object->hDrvr)
+    SendDriverMessage (icm_object->hDrvr, ICM_CONFIGURE,
+# if defined (G_OS_WIN32)
+        widget ? GPOINTER_TO_INT (GDK_WINDOW_HWND (widget->window)) : 0, 0);
+# elif defined (USE_W32LDR)
+                                                GPOINTER_TO_INT (widget), 0);
+# endif /* defined (USE_W32LDR) */
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ICMパラメータ                                                            *
@@ -551,65 +633,6 @@ icm_set_state (IcmObject *icm_object,
 }
 
 
-/******************************************************************************
-*                                                                             *
-* ja:ICMダイアログ                                                            *
-*                                                                             *
-******************************************************************************/
-/*  ja:Aboutダイアログのサポートを確認する
-    icm_object,IcmObject
-           RET,TRUE:有効,FALSE:無効                                         */
-gboolean
-icm_is_dialog_about (IcmObject *icm_object)
-{
-#if defined (G_OS_WIN32) || defined (USE_W32LDR)
-  return icm_object && icm_object->hDrvr
-        && SendDriverMessage (icm_object->hDrvr, ICM_ABOUT, -1, 0) == ICERR_OK;
-#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
-  return FALSE;
-#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
-}
-
-
-/*  ja:Aboutダイアログを表示する
-    icm_object,IcmObject                                                    */
-void
-icm_dialog_about (IcmObject *icm_object)
-{
-#if defined (G_OS_WIN32) || defined (USE_W32LDR)
-  if (icm_object && icm_object->hDrvr)
-    SendDriverMessage (icm_object->hDrvr, ICM_ABOUT, 0, 0);
-#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
-}
-
-
-/*  ja:設定ダイアログのサポートを確認する
-    icm_object,IcmObject
-           RET,TRUE:有効,FALSE:無効                                         */
-gboolean
-icm_is_dialog_configure (IcmObject *icm_object)
-{
-#if defined (G_OS_WIN32) || defined (USE_W32LDR)
-  return icm_object && icm_object->hDrvr
-    && SendDriverMessage (icm_object->hDrvr, ICM_CONFIGURE, -1, 0) == ICERR_OK;
-#else /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
-  return FALSE;
-#endif /* not defined (G_OS_WIN32) || defined (USE_W32LDR) */
-}
-
-
-/*  ja:設定ダイアログを表示する
-    icm_object,IcmObject                                                    */
-void
-icm_dialog_configure (IcmObject *icm_object)
-{
-#if defined (G_OS_WIN32) || defined (USE_W32LDR)
-  if (icm_object && icm_object->hDrvr)
-    SendDriverMessage (icm_object->hDrvr, ICM_CONFIGURE, 0, 0);
-#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
-}
-
-
 /******************************************************************************
 *                                                                             *
 * en:ICM Compress                                                             *
@@ -875,10 +898,10 @@ icm_compress_end (IcmObject *icm_object)
         output,圧縮されたデータ
            RET,フレームのサイズ,0:エラー                                    */
 gsize
-icm_compress (IcmObject *icm_object,
-              gboolean  *key_frame,
-              gpointer   input,
-              gpointer   output)
+icm_compress (IcmObject      *icm_object,
+              gboolean       *key_frame,
+              const gpointer  input,
+              gpointer        output)
 {
 #if defined (G_OS_WIN32) || defined (USE_W32LDR)
   DWORD dwFlags,dwID;
@@ -1087,10 +1110,10 @@ icm_decompress_end (IcmObject *icm_object)
         output,展開されたデータ
            RET,TRUE:正常終了,FALSE:エラー                                   */
 gboolean
-icm_decompress (IcmObject   *icm_object,
-                const guint  flags,
-                gpointer     input,
-                gpointer     output)
+icm_decompress (IcmObject      *icm_object,
+                const guint     flags,
+                const gpointer  input,
+                gpointer        output)
 {
 #if defined (G_OS_WIN32) || defined (USE_W32LDR)
   ICDECOMPRESS icdecompress;
