@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,8 +17,6 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "prop.h"
-#include <gdk/gdkkeysyms.h>
-#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -419,7 +417,7 @@ prop_dialog_changed (GtkWidget      *widget,
     {
       text = gtk_entry_get_text
 #if GTK_CHECK_VERSION(2,4,0)
-                            (GTK_ENTRY (GTK_BIN (propdlg->combo0)->child));
+                (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg->combo0))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
                             (GTK_ENTRY (GTK_COMBO (propdlg->combo0)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -433,7 +431,7 @@ prop_dialog_changed (GtkWidget      *widget,
     {
       text = gtk_entry_get_text
 #if GTK_CHECK_VERSION(2,4,0)
-                                (GTK_ENTRY (GTK_BIN (propdlg->combo1)->child));
+                (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg->combo1))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
                             (GTK_ENTRY (GTK_COMBO (propdlg->combo1)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -468,18 +466,6 @@ prop_dialog_changed_entry (GtkWidget      *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-prop_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:プロパティダイアログ表示
     propcfg,プロパティ構造体
         RET,TRUE:OK,FALSE:Cancel                                            */
@@ -487,9 +473,10 @@ gboolean
 property_dialog (PropertyConfig *propcfg)
 {
   gboolean result;
-  gchar *text;
+  gchar *text, *title;
   gint i;
   GList *glist;
+  GtkStockItem stock_item;
   GtkWidget *combo, *entry0, *entry1, *radio0, *radio1;
   GtkWidget *spin0, *spin1, *spin2, *spin3;
   GtkWidget *label0, *label1, *label2, *label3, *label4;
@@ -505,15 +492,18 @@ property_dialog (PropertyConfig *propcfg)
                    {N_("Full Color"), 24}, {N_("32 bits"),   32}, {NULL, 0}};
 
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_PROPERTIES, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   propdlg.dialog = gtk_dialog_new_with_buttons
-                            (_("Property"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (propdlg.dialog), "key-press-event",
-                                    G_CALLBACK (prop_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (propdlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:エントリー */
   propdlg.entry = gtk_entry_new ();
   text = misc_str_from_float (propcfg->rate, propcfg->scale);
@@ -551,7 +541,8 @@ property_dialog (PropertyConfig *propcfg)
         if (lang[i].id == propcfg->language0)
           {
 #if GTK_CHECK_VERSION(2,4,0)
-            gtk_entry_set_text (GTK_ENTRY (GTK_BIN (propdlg.combo0)->child),
+            gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo0))),
                                                             _(lang[i].text));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
             gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (propdlg.combo0)->entry),
@@ -563,8 +554,8 @@ property_dialog (PropertyConfig *propcfg)
         {
           text = g_strdup_printf ("%X", propcfg->language0);
 #if GTK_CHECK_VERSION(2,4,0)
-          gtk_entry_set_text (GTK_ENTRY (GTK_BIN (propdlg.combo0)->child),
-                                                                        text);
+          gtk_entry_set_text
+            (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo0))), text);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
           gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (propdlg.combo0)->entry),
                                                                         text);
@@ -572,8 +563,9 @@ property_dialog (PropertyConfig *propcfg)
           g_free (text);
         }
 #if GTK_CHECK_VERSION(2,4,0)
-      g_signal_connect (G_OBJECT (GTK_BIN (propdlg.combo0)->child), "changed",
-                                G_CALLBACK (prop_dialog_changed), &propdlg);
+      g_signal_connect
+                    (G_OBJECT (gtk_bin_get_child (GTK_BIN (propdlg.combo0))),
+                        "changed", G_CALLBACK (prop_dialog_changed), &propdlg);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       g_signal_connect (G_OBJECT (GTK_COMBO (propdlg.combo0)->entry),
                         "changed", G_CALLBACK (prop_dialog_changed), &propdlg);
@@ -664,7 +656,7 @@ property_dialog (PropertyConfig *propcfg)
       gtk_label_set_mnemonic_widget (GTK_LABEL (label2), spin0);
 #if GTK_CHECK_VERSION(2,4,0)
       gtk_label_set_mnemonic_widget (GTK_LABEL (label3),
-                                            GTK_BIN (propdlg.combo0)->child);
+                                gtk_bin_get_child (GTK_BIN (propdlg.combo0)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_label_set_mnemonic_widget (GTK_LABEL (label3),
                                             GTK_COMBO (propdlg.combo0)->entry);
@@ -760,7 +752,8 @@ property_dialog (PropertyConfig *propcfg)
         if (lang[i].id == propcfg->language1)
           {
 #if GTK_CHECK_VERSION(2,4,0)
-            gtk_entry_set_text (GTK_ENTRY (GTK_BIN (propdlg.combo1)->child),
+            gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo1))),
                                                             _(lang[i].text));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
             gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (propdlg.combo1)->entry),
@@ -772,8 +765,8 @@ property_dialog (PropertyConfig *propcfg)
         {
           text = g_strdup_printf ("%X", propcfg->language1);
 #if GTK_CHECK_VERSION(2,4,0)
-          gtk_entry_set_text (GTK_ENTRY (GTK_BIN (propdlg.combo1)->child),
-                                                                        text);
+          gtk_entry_set_text
+            (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo1))), text);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
           gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (propdlg.combo1)->entry),
                                                                         text);
@@ -781,8 +774,9 @@ property_dialog (PropertyConfig *propcfg)
           g_free (text);
         }
 #if GTK_CHECK_VERSION(2,4,0)
-      g_signal_connect (G_OBJECT (GTK_BIN (propdlg.combo1)->child), "changed",
-                                G_CALLBACK (prop_dialog_changed), &propdlg);
+      g_signal_connect
+                    (G_OBJECT (gtk_bin_get_child (GTK_BIN (propdlg.combo1))),
+                        "changed", G_CALLBACK (prop_dialog_changed), &propdlg);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       g_signal_connect (G_OBJECT (GTK_COMBO (propdlg.combo1)->entry),
                         "changed", G_CALLBACK (prop_dialog_changed), &propdlg);
@@ -820,7 +814,7 @@ property_dialog (PropertyConfig *propcfg)
       gtk_label_set_mnemonic_widget (GTK_LABEL (label2), spin3);
 #if GTK_CHECK_VERSION(2,4,0)
       gtk_label_set_mnemonic_widget (GTK_LABEL (label3),
-                                            GTK_BIN (propdlg.combo1)->child);
+                                gtk_bin_get_child (GTK_BIN (propdlg.combo1)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_label_set_mnemonic_widget (GTK_LABEL (label3),
                                             GTK_COMBO (propdlg.combo1)->entry);
@@ -951,7 +945,7 @@ property_dialog (PropertyConfig *propcfg)
           /* ja:言語 */
           text = gtk_entry_get_text
 #if GTK_CHECK_VERSION(2,4,0)
-                                (GTK_ENTRY (GTK_BIN (propdlg.combo0)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo0))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
                             (GTK_ENTRY (GTK_COMBO (propdlg.combo0)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -994,7 +988,7 @@ property_dialog (PropertyConfig *propcfg)
           /* ja:言語 */
           text = gtk_entry_get_text
 #if GTK_CHECK_VERSION(2,4,0)
-                                (GTK_ENTRY (GTK_BIN (propdlg.combo1)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (propdlg.combo1))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
                             (GTK_ENTRY (GTK_COMBO (propdlg.combo1)->entry));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
