@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "size.h"
-#include <gdk/gdkkeysyms.h>
 
 
 /******************************************************************************
@@ -139,18 +138,6 @@ size_dialog_activate (GtkWidget  *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-size_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:サイズ変更ダイアログ表示
     sizecfg,サイズ変更構造体
         RET,TRUE:OK,FALSE:Cancel                                            */
@@ -172,11 +159,11 @@ size_dialog (SizeConfig *sizecfg)
                             (_("Size"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (sizedlg.dialog), "key-press-event",
-                                    G_CALLBACK (size_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (sizedlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ボタン */
   if (sizecfg->def_width > 0 && sizecfg->def_height > 0)
     {
@@ -196,10 +183,6 @@ size_dialog (SizeConfig *sizecfg)
                             G_CALLBACK (size_dialog_clicked_button), &sizedlg);
       g_signal_connect (G_OBJECT (button3), "clicked",
                             G_CALLBACK (size_dialog_clicked_button), &sizedlg);
-      GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-      GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-      GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
-      GTK_WIDGET_SET_FLAGS (button3, GTK_CAN_DEFAULT);
     }
   else
     {
@@ -221,10 +204,6 @@ size_dialog (SizeConfig *sizecfg)
                             G_CALLBACK (size_dialog_clicked_button), &sizedlg);
   g_signal_connect (G_OBJECT (button7), "clicked",
                             G_CALLBACK (size_dialog_clicked_button), &sizedlg);
-  GTK_WIDGET_SET_FLAGS (button4, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button5, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button6, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (button7, GTK_CAN_DEFAULT);
   /* ja:チェックボタン */
   if (sizecfg->def_width > 0 && sizecfg->def_height > 0)
     {
