@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,13 +17,21 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "general.h"
+#if GTK_CHECK_VERSION(2,8,0)
+# include "icons.h"
+#endif /* GTK_CHECK_VERSION(2,8,0) */
 #include "thread.h"
-#include "toolbar.h"
+#include "misc/fileio.h"
 #include "orz/orzmdi.h"
-#ifndef USE_THREAD
-#include "misc/misc.h"
-#endif /* not USE_THREAD */
 #include <time.h>
+#if defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME_H)
+# include <sys/time.h>
+#endif /* defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME_H) */
+#ifdef G_OS_WIN32
+# include <windows.h>
+# include <tchar.h>
+# include <time.h>
+#endif /* G_OS_WIN32 */
 
 
 /******************************************************************************
@@ -52,7 +60,6 @@ thread_set_menu_bar (gboolean task)
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/edit"), task);
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/view"), task);
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/option"), task);
-  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/task"), !task);
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/window"), task);
   gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/help"), task);
   for (i = 0; toolbar_entries[i].path; i++)
@@ -82,13 +89,17 @@ thread_insert (gint         id,
                const gchar *file)
 #endif /* not USE_THREAD */
 {
-  gchar *text[4];
-  gchar *name[] = {N_("Exit"), N_("Open"), N_("Save"), N_("Change Frames"),
-                                                                N_("Reverse")};
-  gint i;
+  const gchar *fmt = "%c";
+  gchar str[512], *text_mode, *text_file, *text_time;
+  GtkListStore *store;
+  GtkStockItem stock_item;
   GtkTreeIter iter;
-  time_t tm;
   ThreadList *tl;
+#if GTK_CHECK_VERSION(2,8,0)
+  const gchar *stock_id;
+  GdkPixbuf *pixbuf_mode, *pixbuf_file;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+  time_t t;
 
   tl = g_malloc (sizeof (ThreadList));
   tl->mode = mode;
@@ -96,32 +107,118 @@ thread_insert (gint         id,
   tl->userbreak = TRUE;
   tl->id = id;
   /* ja:モード */
-  text[0] = _(name[mode]);
+  switch (mode)
+    {
+      case THREAD_MODE_EXIT:
+        gtk_stock_lookup (GTK_STOCK_QUIT, &stock_item);
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = NULL;
+        stock_id = stock_item.stock_id;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = misc_mnemonic_to_text (stock_item.label);
+        break;
+      case THREAD_MODE_OPEN:
+        gtk_stock_lookup (GTK_STOCK_OPEN, &stock_item);
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = NULL;
+        stock_id = stock_item.stock_id;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = misc_mnemonic_to_text (stock_item.label);
+        break;
+      case THREAD_MODE_SAVE:
+        gtk_stock_lookup (GTK_STOCK_SAVE_AS, &stock_item);
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = NULL;
+        stock_id = stock_item.stock_id;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = misc_mnemonic_to_text (stock_item.label);
+        break;
+      case THREAD_MODE_CHANGE:
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = gdk_pixbuf_new_from_xpm_data (change16_xpm);
+        stock_id = NULL;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = g_strdup (_("Change Frames"));
+        break;
+      case THREAD_MODE_REVERSE:
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = gdk_pixbuf_new_from_xpm_data (reverse16_xpm);
+        stock_id = NULL;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = g_strdup (_("Reverse"));
+        break;
+      default:
+#if GTK_CHECK_VERSION(2,8,0)
+        pixbuf_mode = NULL;
+        stock_id = NULL;
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+        text_mode = NULL;
+    }
   /* ja:ファイル名 */
-  text[1] = g_filename_to_utf8 (file != NULL ? file : "", -1,
-                                                            NULL, NULL, NULL);
+#if GTK_CHECK_VERSION(2,8,0)
+  pixbuf_file = fileio_extract_icon (file, FILEIO_ICON_SIZE_SMALL);
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+#if GLIB_CHECK_VERSION(2,6,0)
+  text_file = file ? g_filename_display_name (file) : NULL;
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
+  text_file = file ? g_filename_to_utf8 (file, -1, NULL, NULL, NULL) : NULL;
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
   /* ja:時刻 */
-  tm = time (NULL);
-  text[2] = ctime (&tm);
-  /* ja:進行状況 */
-  text[3] = "0";
+  t = time (NULL);
+  if (strftime (str, sizeof (str), fmt, localtime (&t)) > 0)
+    {
+      text_time = g_locale_to_utf8 (str, -1, NULL, NULL, NULL);
+    }
+  else
+    {
+      gsize length;
+
+      text_time = g_locale_to_utf8 (ctime (&t), -1, NULL, NULL, NULL);
+      length = g_strlen (text_time);
+      if (text_time[length - 1] == '\n')
+        text_time[length - 1] = '\0';
+    }
   /* ja:設定 */
 #ifdef USE_THREAD
   G_LOCK (critical);
   critical = TRUE;
   gdk_threads_enter ();
 #endif /* USE_THREAD */
-  gtk_list_store_append (list_store, &iter);
-  for (i = 0; i < 4; i++)
-    gtk_list_store_set (list_store, &iter, i, text[i], -1);
-  gtk_list_store_set (list_store, &iter, 4, tl, -1);
+  store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tview)));
+  gtk_list_store_append (store, &iter);
+  gtk_list_store_set (store, &iter,
+#if GTK_CHECK_VERSION(2,8,0)
+                                        THREAD_TVIEW_MODE_PIXBUF, pixbuf_mode,
+                                        THREAD_TVIEW_MODE_STOCK,  stock_id,
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+                                        THREAD_TVIEW_MODE_TEXT,   text_mode,
+#if GTK_CHECK_VERSION(2,8,0)
+                                        THREAD_TVIEW_FILE_PIXBUF, pixbuf_file,
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+                                        THREAD_TVIEW_FILE_TEXT,   text_file,
+                                        THREAD_TVIEW_TIME,        text_time,
+#if GTK_CHECK_VERSION(2,6,0)
+                                        THREAD_TVIEW_STATUS_PROG, 0,
+                                        THREAD_TVIEW_STATUS_TEXT, NULL,
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+                                        THREAD_TVIEW_STATUS_TEXT, "0",
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+                                        THREAD_TVIEW_POINTER,     tl, -1);
   gtk_tree_view_columns_autosize (GTK_TREE_VIEW (tview));
 #ifdef USE_THREAD
   gdk_threads_leave ();
   critical = FALSE;
   G_UNLOCK (critical);
 #endif /* USE_THREAD */
-  g_free (text[1]);
+#if GTK_CHECK_VERSION(2,8,0)
+  if (pixbuf_mode)
+    g_object_unref (pixbuf_mode);
+  if (pixbuf_file)
+    g_object_unref (pixbuf_file);
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+  g_free (text_mode);
+  g_free (text_file);
+  g_free (text_time);
 #ifndef USE_THREAD
   thread_set_menu_bar (FALSE);
   gtk_widget_set_sensitive (mdi, FALSE);
@@ -141,7 +238,8 @@ gboolean
 thread_delete(gint id)
 #endif /* not USE_THREAD */
 {
-  gint i, count;
+  gint i;
+  GtkListStore *store;
   GtkTreeIter iter;
   ThreadList *tl;
 #ifndef USE_THREAD
@@ -154,17 +252,18 @@ thread_delete(gint id)
   gdk_threads_enter ();
 #endif /* USE_THREAD */
   /* ja:IDに一致するアイテムを探す */
-  count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (list_store), NULL);
-  for (i = count - 1; i >= 0; i--)
+  store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tview)));
+  for (i = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL) - 1;
+                                                                i >= 0; i--)
     {
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
-                                                            &iter, NULL, i);
-      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
       if (tl->id == id)
         {
           /* ja:リストにアイテムがあるとき */
           g_free (tl);
-          gtk_list_store_remove (list_store, &iter);
+          gtk_list_store_remove (store, &iter);
         }
     }
 #ifdef USE_THREAD
@@ -173,12 +272,12 @@ thread_delete(gint id)
   G_UNLOCK (critical);
 #else /* not USE_THREAD */
   /* ja:IDに一致するアイテムを探す */
-  count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (list_store), NULL);
-  for (i = count - 1; i >= 0; i--)
+  for (i = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL) - 1;
+                                                                i >= 0; i--)
     {
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
-                                                            &iter, NULL, i);
-      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
       switch (tl->id)
         {
           case THREAD_ID_STANDARD: id_standard++; break;
@@ -211,8 +310,8 @@ thread_idling (gint       id,
                const gint percent)
 #endif /* not USE_THREAD */
 {
-  gchar *text;
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter;
   ThreadList *tl = NULL;
 
@@ -221,11 +320,13 @@ thread_idling (gint       id,
   critical = TRUE;
   gdk_threads_enter ();
 #endif /* USE_THREAD */
+  store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tview)));
   /* ja:IDに一致するアイテムを探す */
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter, NULL, i); i++)
     {
-      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
       if (tl->id == id)
         break;
     }
@@ -240,12 +341,27 @@ thread_idling (gint       id,
     }
   if (tl->userbreak && tl->percent != percent)
     {
+#if ! GTK_CHECK_VERSION(2,6,0)
+      gchar *text;
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+
       /* ja:中断ではなくかつ進行状況が異なるとき */
       tl->percent = percent;
+#if GTK_CHECK_VERSION(2,6,0)
+      if (0 <= percent && percent <= 100)
+        gtk_list_store_set (store, &iter,
+                                        THREAD_TVIEW_STATUS_TEXT, NULL,
+                                        THREAD_TVIEW_STATUS_PROG, percent, -1);
+      else
+        gtk_list_store_set (store, &iter,
+                                        THREAD_TVIEW_STATUS_TEXT, _("Error"),
+                                        THREAD_TVIEW_STATUS_PROG, 0, -1);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
       text = percent >= 0
                     ? g_strdup_printf ("%d", percent) : g_strdup (_("Error"));
-      gtk_list_store_set (list_store, &iter, 3, text, -1);
+      gtk_list_store_set (store, &iter, THREAD_TVIEW_STATUS_TEXT, text, -1);
       g_free (text);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
     }
 #ifdef USE_THREAD
   gdk_threads_leave ();
@@ -266,6 +382,7 @@ gboolean
 thread_break (const gboolean all)
 {
   gint i;
+  GtkListStore *store;
   GtkTreeIter iter;
   GtkTreeSelection *select;
   ThreadList *tl;
@@ -274,16 +391,25 @@ thread_break (const gboolean all)
   G_LOCK (critical);
   critical = TRUE;
 #endif /* USE_THREAD */
+  store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tview)));
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter, NULL, i); i++)
     if (all || gtk_tree_selection_iter_is_selected (select, &iter))
       {
-        gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
         if (tl->userbreak)
           {
             tl->userbreak = FALSE;
-            gtk_list_store_set (list_store, &iter, 3, "*", -1);
+#if GTK_CHECK_VERSION(2,6,0)
+            gtk_list_store_set (store, &iter,
+                                            THREAD_TVIEW_STATUS_TEXT, "*",
+                                            THREAD_TVIEW_STATUS_PROG, 0, -1);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+            gtk_list_store_set (store, &iter,
+                                            THREAD_TVIEW_STATUS_TEXT, "*", -1);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
           }
       }
 #ifdef USE_THREAD
@@ -300,6 +426,7 @@ close_program (void)
 {
   gboolean result;
   gint i, count, length;
+  GtkListStore *store;
   GtkTreeIter iter;
   ThreadList *tl;
 #ifdef USE_THREAD
@@ -319,16 +446,23 @@ close_program (void)
   gdk_threads_enter ();
 #endif /* USE_THREAD */
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tview)));
   /* ja:エラーになっているアイテムを探す */
-  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
+  for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
                                                         &iter, NULL, i); i++)
     {
-      gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
       if (tl->percent < 0 && tl->userbreak) /* ja:リストにアイテムがあるとき */
         {
           /* ja:表示を変更する */
           tl->userbreak = FALSE;
-          gtk_list_store_set (list_store, &iter, 3, "*", -1);
+#if GTK_CHECK_VERSION(2,6,0)
+          gtk_list_store_set (store, &iter, THREAD_TVIEW_STATUS_TEXT, "*",
+                                            THREAD_TVIEW_STATUS_PROG, 0, -1);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+          gtk_list_store_set (store, &iter, THREAD_TVIEW_STATUS_TEXT, "*", -1);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
         }
     }
 
@@ -347,13 +481,13 @@ close_program (void)
 
       /* ja:終了スレッドに一致するアイテムを探す */
       result = FALSE;
-      count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (list_store),
-                                                                        NULL);
+      count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL);
       for (i = count - 1; i >= 0; i--)
         {
-          gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store), &iter,
+          gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter,
                                                                     NULL, i);
-          gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 4, &tl, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+                                                THREAD_TVIEW_POINTER, &tl, -1);
           if (tl->mode == THREAD_MODE_EXIT)
             {
               /* ja:リストにアイテムがあるとき */
