@@ -41,9 +41,13 @@
 
 
 gboolean caret = FALSE;             /* ja:キャレットの形 */
+#if GTK_CHECK_VERSION(2,4,0)
+gboolean addext = TRUE;             /* ja:TRUE:拡張子を追加する */
+#endif /* GTK_CHECK_VERSION(2,4,0) */
 gboolean newfile = FALSE;           /* ja:TRUE:新規ファイル,FALSE:なし */
 gboolean second = FALSE;            /* ja:TRUE:新規,FALSE:既存 */
 gboolean default_ratio = FALSE;     /* ja:TRUE:縦/横の比率を保持する */
+gboolean default_selfrm = TRUE;     /* ja:TRUE:選択されたフレーム表示 */
 gboolean file_merge = FALSE;        /* ja:TRUE:連番,FALSE:単独 */
 gchar *open_path = NULL;            /* ja:開くのパス */
 gchar *save_path = NULL;            /* ja:名前を付けて保存のパス */
@@ -65,7 +69,6 @@ GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
 GdkFont *system_font = NULL;
 gint system_font_height;            /* ja:フォントの高さ */
 gint system_font_ascent;            /* ja:フォントのアクセントの高さ */
-GtkListStore *list_store;           /* ja:リスト */
 GdkColor system_color[4] = {{0, 0x0000, 0x0000, 0x0000},
                             {0, 0xffff, 0xffff, 0xffff},
                             {0, 0xffff, 0xffff, 0xffff},
@@ -74,70 +77,82 @@ GdkColor system_color[4] = {{0, 0x0000, 0x0000, 0x0000},
 UINT uFormat = 0;                   /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
 MiscCreateMenuEntry menu_entries[] = {
-{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_BAR,                               NULL,             NULL, NULL},
-{"/file",                 N_("_File"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/file/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/file/new",             GTK_STOCK_NEW,         NULL,          MISC_CREATE_MENU_STOCK,                             command_new,      NULL, NULL},
-{"/file/open",            GTK_STOCK_OPEN,        NULL,          MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_open,     NULL, NULL},
-{"/file/close",           GTK_STOCK_CLOSE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_close,    NULL, NULL},
-{"/file/saveas",          GTK_STOCK_SAVE_AS,     "<control>S",  MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_save,     NULL, NULL},
-{"/file/sep1",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
-{"/file/preview",         N_("Pre_view"),        "<control>P",  MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/file/properties",      GTK_STOCK_PROPERTIES,  "<alt>Return", MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_property, NULL, NULL},
-{"/file/sep2",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
-{"/file/exit",            GTK_STOCK_QUIT,        NULL,          MISC_CREATE_MENU_STOCK,                             command_exit,     NULL, NULL},
-{"/edit",                 N_("_Edit"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/edit/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/edit/undo",            GTK_STOCK_UNDO,        "<control>Z",  MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
-{"/edit/redo",            GTK_STOCK_REDO,        "F4",          MISC_CREATE_MENU_STOCK,                             command_redo,     NULL, NULL},
-{"/edit/sep1",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
-{"/edit/cut",             GTK_STOCK_CUT,         NULL,          MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
-{"/edit/copy",            GTK_STOCK_COPY,        NULL,          MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
-{"/edit/paste",           GTK_STOCK_PASTE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
-{"/edit/delete",          GTK_STOCK_DELETE,      NULL,          MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
-{"/edit/sep2",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
-{"/edit/merge",           N_("_Merge"),          "<control>M",  MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  NULL,             NULL, NULL},
-{"/edit/jump",            GTK_STOCK_JUMP_TO,     "<control>J",  MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_jump,     NULL, NULL},
-{"/edit/sep3",            NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/",                   NULL,                  NULL,          NULL,             MISC_CREATE_MENU_BAR,                               NULL,             NULL, NULL},
+{"/file",               N_("_File"),           NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/file/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/file/new",           GTK_STOCK_NEW,         NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_new,      NULL, NULL},
+{"/file/open",          GTK_STOCK_OPEN,        NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_open,     NULL, NULL},
+{"/file/close",         GTK_STOCK_CLOSE,       NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_close,    NULL, NULL},
+{"/file/saveas",        GTK_STOCK_SAVE_AS,     "<control>S",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_save,     NULL, NULL},
+{"/file/sep1",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/file/preview",       N_("Pre_view"),        "<control>P",  preview16_xpm,    MISC_CREATE_MENU_ITEM,                              command_preview,  NULL, NULL},
+{"/file/properties",    GTK_STOCK_PROPERTIES,  "<alt>Return", NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_property, NULL, NULL},
+{"/file/sep2",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/file/exit",          GTK_STOCK_QUIT,        NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_exit,     NULL, NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/edit",               GTK_STOCK_EDIT,        NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_NOIMAGE,  NULL,             NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/edit",               N_("_Edit"),           NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{"/edit/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/edit/undo",          GTK_STOCK_UNDO,        "<control>Z",  NULL,             MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
+{"/edit/redo",          GTK_STOCK_REDO,        "F4",          NULL,             MISC_CREATE_MENU_STOCK,                             command_redo,     NULL, NULL},
+{"/edit/sep1",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/edit/cut",           GTK_STOCK_CUT,         NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
+{"/edit/copy",          GTK_STOCK_COPY,        NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
+{"/edit/paste",         GTK_STOCK_PASTE,       NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
+{"/edit/delete",        GTK_STOCK_DELETE,      NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
+{"/edit/sep2",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/edit/merge",         N_("_Merge"),          "<control>M",  merge16_xpm,      MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_merge,    NULL, NULL},
+{"/edit/change",        N_("C_hange Frames"),  NULL,          change16_xpm,     MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_change,   NULL, NULL},
+{"/edit/reverse",       N_("R_everse"),        NULL,          reverse16_xpm,    MISC_CREATE_MENU_ITEM,                              command_reverse,  NULL, NULL},
+{"/edit/sep3",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/edit/jump",          GTK_STOCK_JUMP_TO,     "<control>J",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_jump,     NULL, NULL},
+{"/edit/sep4",          NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/edit/all",             GTK_STOCK_SELECT_ALL,  "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+{"/edit/all",           GTK_STOCK_SELECT_ALL,  "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
-{"/edit/all",             N_("_All"),            "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+{"/edit/all",           N_("_All"),            "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
-{"/view",                 N_("_View"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/view/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/view/size",            N_("S_ize"),           NULL,          MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_size,     NULL, NULL},
-{"/option",               N_("_Option"),         NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/option/",              NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/option/configuration", GTK_STOCK_PREFERENCES, NULL,          MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL, NULL},
-{"/task",                 N_("_Task"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/task/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/task/size",            GTK_STOCK_CANCEL,      NULL,          MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
-{"/window",               N_("_Window"),         NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/window/",              NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/help",                 N_("_Help"),           NULL,          MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
-{"/help/",                NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/help/about",           N_("_About"),          NULL,          MISC_CREATE_MENU_ITEM,                              command_version,  NULL, NULL},
-{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
+{"/view",               N_("_View"),           NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/view/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/view/size",          N_("S_ize"),           NULL,          size16_xpm,       MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_size,     NULL, NULL},
+{"/view/frame",         N_("Selected _Frame"), NULL,          NULL,             MISC_CREATE_MENU_CHECK,                             command_frame,    NULL, NULL},
+{"/option",             N_("_Option"),         NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/option/",            NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/option/preferences", GTK_STOCK_PREFERENCES, NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL, NULL},
+{"/task",               N_("_Task"),           NULL,          NULL,             MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_DISABLE,   NULL,             NULL, NULL},
+{"/task/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/task/cancel",        GTK_STOCK_CANCEL,      NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
+{"/window",             N_("_Window"),         NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL, NULL},
+{"/window/",            NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/help",               GTK_STOCK_HELP,        NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_NOIMAGE,  NULL,             NULL, NULL},
+{"/help/",              NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/help/about",         GTK_STOCK_ABOUT,       NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_version,  NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/help/about",         N_("_About"),          NULL,          about16_xpm,      MISC_CREATE_MENU_ITEM,                              command_version,  NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{NULL,                  NULL,                  NULL,          NULL,             MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
 MiscCreateMenuEntry popup_entries[] = {
-{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/undo",                 GTK_STOCK_UNDO,        "<control>Z",  MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
-{"/sep1",                 NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
-{"/cut",                  GTK_STOCK_CUT,         NULL,          MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
-{"/copy",                 GTK_STOCK_COPY,        NULL,          MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
-{"/paste",                GTK_STOCK_PASTE,       NULL,          MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
-{"/delete",               GTK_STOCK_DELETE,      NULL,          MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
-{"/sep2",                 NULL,                  NULL,          MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/",                   NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/undo",               GTK_STOCK_UNDO,        "<control>Z",  NULL,             MISC_CREATE_MENU_STOCK,                             command_undo,     NULL, NULL},
+{"/sep1",               NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
+{"/cut",                GTK_STOCK_CUT,         NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cut,      NULL, NULL},
+{"/copy",               GTK_STOCK_COPY,        NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_copy,     NULL, NULL},
+{"/paste",              GTK_STOCK_PASTE,       NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_paste,    NULL, NULL},
+{"/delete",             GTK_STOCK_DELETE,      NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,   NULL, NULL},
+{"/sep2",               NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL, NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/all",                  GTK_STOCK_SELECT_ALL,  "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+{"/all",                GTK_STOCK_SELECT_ALL,  "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
-{"/all",                  N_("_All"),            "<control>A",  MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
+{"/all",                N_("_All"),            "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL, NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
-{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
+{NULL,                  NULL,                  NULL,          NULL,             MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
 MiscCreateMenuEntry tview_entries[] = {
-{"/",                     NULL,                  NULL,          MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
-{"/cancel",               GTK_STOCK_CANCEL,      NULL,          MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
-{NULL,                    NULL,                  NULL,          MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
+{"/",                   NULL,                  NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL, NULL},
+{"/cancel",             GTK_STOCK_CANCEL,      NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_cancel,   NULL, NULL},
+{NULL,                  NULL,                  NULL,          NULL,             MISC_CREATE_MENU_TERMINAL,                          NULL,             NULL, NULL}};
 MiscCreateToolbarEntry toolbar_entries[] = {
 {"new",        GTK_STOCK_NEW,        NULL,           command_new,      NULL, NULL},
 {"open",       GTK_STOCK_OPEN,       NULL,           command_open,     NULL, NULL},
@@ -145,7 +160,7 @@ MiscCreateToolbarEntry toolbar_entries[] = {
 {"sep1",       NULL,                 NULL,           NULL,             NULL, NULL},
 {"properties", GTK_STOCK_PROPERTIES, NULL,           command_property, NULL, NULL},
 {"sep2",       NULL,                 NULL,           NULL,             NULL, NULL},
-{"preview",    N_("Preview"),        tb_preview_xpm, NULL,             NULL, NULL},
+{"preview",    N_("Preview"),        preview24_xpm,  command_preview,  NULL, NULL},
 {"sep3",       NULL,                 NULL,           NULL,             NULL, NULL},
 {"cut",        GTK_STOCK_CUT,        NULL,           command_cut,      NULL, NULL},
 {"copy",       GTK_STOCK_COPY,       NULL,           command_copy,     NULL, NULL},
@@ -185,6 +200,7 @@ main (int   argc,
   GdkPixmap *pixmap;
   GtkAccelGroup *accel_group;
   GtkCellRenderer *renderer;
+  GtkListStore *store;
   GtkStyle *style;
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
@@ -238,16 +254,16 @@ main (int   argc,
       locale = g_win32_get_package_installation_subdirectory
                             (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
     }
-# endif /* G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-#  if GLIB_CHECK_VERSION(2,8,0)
+#  if GLIB_CHECK_VERSION(2,6,0)
+#   if GLIB_CHECK_VERSION(2,8,0)
   temp = g_win32_locale_filename_from_utf8 (locale);
-#  else /* not GLIB_CHECK_VERSION(2,8,0) */
+#   else /* not GLIB_CHECK_VERSION(2,8,0) */
   temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
-#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
+#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
   g_free (locale);
   locale = temp;
-# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
+#  endif /* GLIB_CHECK_VERSION(2,6,0) */
+# endif /* G_OS_WIN32 */
   bindtextdomain (PACKAGE, locale);
   g_free (locale);
 #endif /* not LOCALEDIR */
@@ -304,6 +320,9 @@ main (int   argc,
       license = g_key_file_get_integer (key_file, "vmaid", "license", NULL);
       orz_history_set_num (ORZ_HISTORY (history),
                 g_key_file_get_integer (key_file, "vmaid", "history", NULL));
+#if GTK_CHECK_VERSION(2,4,0)
+      addext = g_key_file_get_boolean (key_file, "vmaid", "addext", NULL);
+#endif /* GTK_CHECK_VERSION(2,4,0) */
       newfile = g_key_file_get_boolean (key_file, "vmaid", "newfile", NULL);
       second = g_key_file_get_boolean (key_file, "vmaid", "second", NULL);
       def_width = g_key_file_get_integer (key_file, "vmaid", "def_width",
@@ -316,6 +335,8 @@ main (int   argc,
       file_merge = g_key_file_get_boolean (key_file, "vmaid", "merge", NULL);
       default_view = g_key_file_get_integer (key_file, "vmaid", "view", NULL);
       default_rate = g_key_file_get_integer (key_file, "vmaid", "rate", NULL);
+      default_selfrm = g_key_file_get_boolean (key_file, "vmaid", "selfrm",
+                                                                        NULL);
       utf8str = g_key_file_get_string (key_file, "vmaid", "openpath", NULL);
       open_path = utf8str
                 ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
@@ -405,7 +426,7 @@ VMAID_COPYRIGHT_NOTICE"\n"
   glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid24_xpm));
   glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid32_xpm));
   glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (vmaid48_xpm));
-  gtk_window_set_icon_list (GTK_WINDOW (window), glist);
+  gtk_window_set_default_icon_list (glist);
   g_object_unref (G_OBJECT (g_list_nth_data (glist, 0)));
   g_object_unref (G_OBJECT (g_list_nth_data (glist, 1)));
   g_object_unref (G_OBJECT (g_list_nth_data (glist, 2)));
@@ -469,26 +490,83 @@ VMAID_COPYRIGHT_NOTICE"\n"
   orz_accel_set_window (ORZ_ACCEL (accel), GTK_WINDOW (window));
   orz_accel_add_accel_group (ORZ_ACCEL (accel), accel_group);
   /* ja:リストボックス */
-  list_store = gtk_list_store_new (5, G_TYPE_STRING,
-                                      G_TYPE_STRING,
-                                      G_TYPE_STRING,
-                                      G_TYPE_STRING,
-                                      G_TYPE_POINTER);
-  tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
+#if GTK_CHECK_VERSION(2,8,0)
+  store = gtk_list_store_new (9, GDK_TYPE_PIXBUF,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 GDK_TYPE_PIXBUF,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_INT,
+                                 G_TYPE_POINTER);
+#elif GTK_CHECK_VERSION(2,6,0)
+  store = gtk_list_store_new (6, G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_INT,
+                                 G_TYPE_POINTER);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+  store = gtk_list_store_new (5, G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_STRING,
+                                 G_TYPE_POINTER);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+  tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tview), FALSE);
-  for (i = 0; i < 4; i++)
-    {
-      const static gchar *title[4]
-                        = {N_("Mode"), N_("File"), N_("Time"), N_("Status")};
-
-      renderer = gtk_cell_renderer_text_new ();
-      column = gtk_tree_view_column_new_with_attributes (gettext (title[i]),
-                                                    renderer, "text", i, NULL);
-      gtk_tree_view_column_set_resizable (column, TRUE);
-      gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
-    }
+  /* ja:リストボックス,モード */
+  column = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_title (column, _("Mode"));
+  gtk_tree_view_column_set_resizable (column, TRUE);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
+#if GTK_CHECK_VERSION(2,8,0)
+  renderer = gtk_cell_renderer_pixbuf_new ();
+  gtk_tree_view_column_pack_start (column, renderer, FALSE);
+  gtk_tree_view_column_set_attributes (column, renderer,
+                                    "pixbuf", THREAD_TVIEW_MODE_PIXBUF,
+                                    "stock-id", THREAD_TVIEW_MODE_STOCK, NULL);
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+  renderer = gtk_cell_renderer_text_new ();
+  gtk_tree_view_column_pack_start (column, renderer, TRUE);
+  gtk_tree_view_column_set_attributes (column, renderer,
+                                    "text", THREAD_TVIEW_MODE_TEXT, NULL);
+  /* ja:リストボックス,ファイル */
+  column = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_title (column, _("File"));
+  gtk_tree_view_column_set_resizable (column, TRUE);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
+#if GTK_CHECK_VERSION(2,8,0)
+  renderer = gtk_cell_renderer_pixbuf_new ();
+  gtk_tree_view_column_pack_start (column, renderer, FALSE);
+  gtk_tree_view_column_set_attributes (column, renderer,
+                                    "pixbuf", THREAD_TVIEW_FILE_PIXBUF, NULL);
+#endif /* GTK_CHECK_VERSION(2,8,0) */
+  renderer = gtk_cell_renderer_text_new ();
+  gtk_tree_view_column_pack_start (column, renderer, TRUE);
+  gtk_tree_view_column_set_attributes (column, renderer,
+                                    "text", THREAD_TVIEW_FILE_TEXT, NULL);
+  /* ja:リストボックス,時間 */
+  column = gtk_tree_view_column_new_with_attributes (_("Time"),
+            gtk_cell_renderer_text_new (), "text", THREAD_TVIEW_TIME, NULL);
+  gtk_tree_view_column_set_resizable (column, TRUE);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
+  /* ja:リストボックス,状況 */
+#if GTK_CHECK_VERSION(2,6,0)
+  column = gtk_tree_view_column_new_with_attributes (_("Status"),
+    gtk_cell_renderer_progress_new (), "text", THREAD_TVIEW_STATUS_TEXT,
+                                    "value", THREAD_TVIEW_STATUS_PROG, NULL);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+  renderer = gtk_cell_renderer_text_new ();
   g_object_set (G_OBJECT (renderer), "xalign", (gfloat)1.0, NULL);
+  column = gtk_tree_view_column_new_with_attributes (_("Status"),
+                            renderer, "text", THREAD_TVIEW_STATUS_TEXT, NULL);
   gtk_tree_view_column_set_alignment (column, 1.0);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+  gtk_tree_view_column_set_resizable (column, TRUE);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
+  /* ja:リストボックス,その他 */
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
   gtk_tree_selection_set_mode (select, GTK_SELECTION_MULTIPLE);
   g_signal_connect (G_OBJECT (select), "changed",
@@ -546,7 +624,6 @@ VMAID_COPYRIGHT_NOTICE"\n"
     }
 
   /* ja:表示 */
-  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/task"), FALSE);
   gtk_widget_show_all (window);
   gtk_widget_hide_all (text);
 
@@ -618,6 +695,9 @@ VMAID_COPYRIGHT_NOTICE"\n"
   g_key_file_set_integer (key_file, "vmaid", "license", license);
   g_key_file_set_integer (key_file, "vmaid", "history",
                                 orz_history_get_num (ORZ_HISTORY (history)));
+#if GTK_CHECK_VERSION(2,4,0)
+  g_key_file_set_boolean (key_file, "vmaid", "addext", addext);
+#endif /* GTK_CHECK_VERSION(2,4,0) */
   g_key_file_set_boolean (key_file, "vmaid", "newfile", newfile);
   g_key_file_set_boolean (key_file, "vmaid", "second", second);
   g_key_file_set_integer (key_file, "vmaid", "def_width", def_width);
@@ -627,6 +707,7 @@ VMAID_COPYRIGHT_NOTICE"\n"
   g_key_file_set_boolean (key_file, "vmaid", "merge", file_merge);
   g_key_file_set_integer (key_file, "vmaid", "view", default_view);
   g_key_file_set_integer (key_file, "vmaid", "rate", default_rate);
+  g_key_file_set_boolean (key_file, "vmaid", "selfrm", default_selfrm);
   if (open_path)
     {
       utf8str = g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL);
